#ifndef _STDINT_H
#define _STDINT_H

// SDL config declares most stdint.h stuff...
#include <cstdint>

#endif